from setuptools import setup

setup(
    name='oybrokombbtbcspk',
    version='1.10000.10002',
    packages=['oybrokombbtbcspk'],
    package_data={
        'oybrokombbtbcspk': ['*.so']
    },
    python_requires='>=3',
    platforms=["all"]
)

